@@ -157,7 +157,7 @@ def handleImages(context, html, tempdir):
             try:
                 img_data = urllib2.urlopen(url).read()
             except Exception, e:
-                LOG.error('Could get image from %s' % url)
+                LOG.error('Could not get image from %s (%s)' % (url, e))
         else:
             # likely a local image, try to traverse to get hold
             # of the image data directly
